@@ -1,6 +1,7 @@
 import time, json, threading
 from requests import get
 
+
 _DEFAULT_INTERVAL_READ = 5000
 _DEFAULT_INTERVAL_WRITE = 3000
 _MAX_TRIES = 10
@@ -34,8 +35,9 @@ class Panel:
     __panel_size = 0
     localUpdated = False
     siteUpdated = False
+    lastStatus = 0
 
-    __state = {}#{"myInt": [42, False, _MAX_TRIES], "myfloat": [3.14, False, _MAX_TRIES]}
+    __state = {}
 
 
     def __init__(self, name, key = None):
@@ -59,7 +61,7 @@ class Panel:
 
     def __getattr__(self, item):
 
-        if item.startswith("_"):
+        if item.startswith("_") or item == "localUpdated" or item == "siteUpdated" or item == "lastStatus":
             super(Panel, self).__getattr__(item)
 
         else:
@@ -75,9 +77,13 @@ class Panel:
 
     def __setattr__(self, item, new_val):
 
-        if item.startswith("_") or item == "localUpdated" or item == "siteUpdated":
+        if item.startswith("_") or item == "localUpdated" or item == "siteUpdated" or item == "lastStatus":
+        #if item.startswith("_") or item == "siteUpdated":
             super(Panel, self).__setattr__(item, new_val)
 
+       # elif item == "localUpdated":
+            #super(Panel, self).__setattr__(item, False)
+
         #print(new_val, self.__state[item][val_index])
         elif new_val != self.__state[item][val_index]:
 
@@ -92,6 +98,14 @@ class Panel:
 
                 raise KeyError('переменной с таким именем нет в панели')
 
+    #condition = threading.Condition()
+    #def setFlag(self):
+        #self.condition.acquire()
+        #self.condition.wait()
+        #self.siteUpdated = True
+        #self.condition.release()
+
+    #b = threading.Barrier(1, action = self.setFlag)
 
     def readUpdate(self):
 
@@ -99,7 +113,9 @@ class Panel:
 
         if not self.__panel_exists:
 
-            return invalidName
+            self.lastStatus = invalidName
+
+            return self.lastStatus
 
 
         if abs(currentTime - self.__read_timestamp) > self.__read_interval\
@@ -121,12 +137,15 @@ class Panel:
         else:
 
             self.localUpdated = False
-            return intervalError
+            self.lastStatus = intervalError
+            return self.lastStatus
 
 
         if response.status_code != httpOk:
 
-            return response.status_code
+            self.lastStatus = response.status_code
+
+            return self.lastStatus
 
 
         j = json.loads(response.text)
@@ -142,13 +161,17 @@ class Panel:
                 self.__panel_exsists = False
                 raise NameError('панель с таким именем не существует')
 
-            return m
+            self.lastStatus = m
+
+            return self.lastStatus
 
         self.__panel_size = j["countVariable"]
 
         if self.__panel_size == 0:
 
-            return emptyBoard
+            self.lastStatus = emptyBoard
+
+            return self.lastStatus
 
         multiplier = self.__devices * len(self.__objCount)
         self.__read_interval = j["mTimeR"] * multiplier
@@ -177,23 +200,41 @@ class Panel:
             self.__state[data["variable"]] = temp
 
         self.localUpdated = True
+        self.lastStatus = OK
 
-        return OK
+        return self.lastStatus
 
 
     def writeUpdate(self):
 
+        #self.b.wait()
+        #if self.b.wait() == 0:
+            #self.siteUpdated = True
+        #self.condition.acquire()
+        #c = threading.activeCount()
+        #print(c)
+
+        # getting the time this function called
         currentTime = self.__millis()
 
+        # if time hasn't come - return error
         if abs(currentTime - self.__write_timestamp) < self.__write_interval:
             self.siteUpdated = False
+            #threading.Timer(self.__write_interval / 1000, self.writeUpdate).start()
+            #siteUpdated = False
+            self.lastStatus = intervalError
             return intervalError
+#        else:
+            #self.setFlag()
+            #self.condition.notify()
+            #self.condition.release()
 
-        #print("test")
+        # writing timestamp of possible request
         self.__write_timestamp = self.__millis()
         req = "https://iocontrol.ru/api/sendDataAll/" + str(self.__name)\
                 + "/" + str(self.__key) + "/"
 
+        # flag for making a request
         writeFlag = False
 
         for k in self.__state:
@@ -218,11 +259,14 @@ class Panel:
 
             if resp.status_code != httpOk:
 
+                self.lastStatus = resp.status_code
+
                 return resp.status_code
 
             j = json.loads(resp.text)
 
             if j["check"] == False:
+                self.lastStatus = j["message"]
                 return j["message"]
 
             data = j["data"]
@@ -246,10 +290,14 @@ class Panel:
                     self.__state[k][pending] = False
 
             #if failed_flag == False:
+            #self.b.wait()
             self.siteUpdated = True
+            #siteUpdated = True
+            self.lastStatus = OK
 
             return OK
         else:
+            self.lastStatus = nothingToWrite
             return nothingToWrite
 
 
